/*
 * i386/types.h
 *
 * Copyright 2008, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef _MACHINE_TYPES_H_
#define	_MACHINE_TYPES_H_


#ifndef ASM_FILE


typedef	char				int8_t;
typedef	short				int16_t;
typedef	int					int32_t;
typedef	long long			int64_t;
typedef	unsigned char		uint8_t;
typedef	unsigned short		uint16_t;
typedef	unsigned int		uint32_t;
typedef	unsigned long long	uint64_t;

typedef char				s8;
typedef short				s16;
typedef int					s32;
typedef long long			s64;
typedef unsigned char		u8;
typedef unsigned short		u16;
typedef unsigned int		u32;
typedef unsigned long long	u64;

typedef uint32_t			mem_addr_t;		// ꡼ɥ쥹
typedef	int					intptr_t;
typedef	unsigned int		uintptr_t;
typedef mem_addr_t			ptrdiff_t;		/* ptr1 - ptr2 */
typedef	mem_addr_t			vm_offset_t;
typedef uint32_t			intrmask_t;
typedef	void				inthand2_t (void *_cookie);

typedef unsigned long		paddr_t;
typedef unsigned long		psize_t;
typedef unsigned long		vsize_t;
typedef unsigned long		vaddr_t;

#define BITS_PER_LONG 32


#endif


#endif /* !_MACHINE_TYPES_H_ */
